# pymatrix-rain
Matrix rain effect using python 3 and curses.

### How to Download
 >pip install pymatrix-rain
 
 to run: pymatrix-rain


##### NOTE:

> not tested on windows or mac

> -p password option is not securely implemented

###  Commands
- **<kbd>Q</kbd>** = *quits*
- **<kbd>b</kbd>** = *bold on*
- **<kbd>B</kbd>** = *bold all*
- **<kbd>n</kbd>** = *bold off*
- **<kbd>0-9</kbd>** = *delay speed*
- **<kbd>a</kbd>** = *asynchronous like scrolling*
- **<kbd>m</kbd>** = *multiple color mode*
- **<kbd>M</kbd>** = *multiple random color mode*
- **<kbd>d</kbd>** = *reset to default*
- **<kbd>c</kbd>** = *cycle through colors automatically*

##### rain colors
- **<kbd>r</kbd>** = red
- **<kbd>t</kbd>** = green
- **<kbd>y</kbd>** = blue
- **<kbd>u</kbd>** = yellow
- **<kbd>i</kbd>** = magenta
- **<kbd>o</kbd>** = cyan
- **<kbd>p</kbd>** = white

##### lead char color
- **<kbd>R</kbd>** = red
- **<kbd>T</kbd>** = green
- **<kbd>Y</kbd>** = blue
- **<kbd>U</kbd>** = yellow
- **<kbd>I</kbd>** = magenta
- **<kbd>O</kbd>** = cyan
- **<kbd>P</kbd>** = white

## Screen Shots

![screen1.png](img/screen1.png?raw=true)

![screen2.png](img/screen2.png?raw=true)

![screen3.png](img/screen3.png?raw=true)

![screen4.png](img/screen4.png?raw=true)
